dlsia.test\_data.two_d package
==================================

Submodules
----------

dlsia.test\_data.two_d.build\_test\_data module
---------------------------------------------------

.. automodule:: dlsia.test_data.two_d.build_test_data
   :members:
   :undoc-members:
   :show-inheritance:

dlsia.test\_data.two_d.diffusion\_model module
--------------------------------------------------

.. automodule:: dlsia.test_data.two_d.diffusion_model
   :members:
   :undoc-members:
   :show-inheritance:

dlsia.test\_data.two_d.noisy\_gauss\_2d module
--------------------------------------------------

.. automodule:: dlsia.test_data.two_d.noisy_gauss_2d
   :members:
   :undoc-members:
   :show-inheritance:

dlsia.test\_data.two_d.noisy\_gauss\_2d\_time module
--------------------------------------------------------

.. automodule:: dlsia.test_data.two_d.noisy_gauss_2d_time
   :members:
   :undoc-members:
   :show-inheritance:

dlsia.test\_data.two_d.random\_shapes module
------------------------------------------------

.. automodule:: dlsia.test_data.two_d.random_shapes
   :members:
   :undoc-members:
   :show-inheritance:

dlsia.test\_data.two_d.torch\_hdf5\_loader module
-----------------------------------------------------

.. automodule:: dlsia.test_data.two_d.torch_hdf5_loader
   :members:
   :undoc-members:
   :show-inheritance:

dlsia.test\_data.two_d.tst module
-------------------------------------

.. automodule:: dlsia.test_data.two_d.tst
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dlsia.test_data.two_d
   :members:
   :undoc-members:
   :show-inheritance:
